==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebGridToolbarDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridBaseDirectiveDescriptionMetadata } from "./WebGridBaseDirectiveDescriptionMetadata";
import { WebDisplayDensityBaseElementDescriptionMetadata } from "./WebDisplayDensityBaseElementDescriptionMetadata";
import { WebGridToolbarDescription } from "./WebGridToolbarDescription";
/**
 * @hidden
 */
var WebGridToolbarDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebGridToolbarDescriptionMetadata, _super);
    function WebGridToolbarDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridToolbarDescriptionMetadata.b = function (a) {
        if (WebGridToolbarDescriptionMetadata.a == null) {
            WebGridToolbarDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridToolbarDescriptionMetadata.c(WebGridToolbarDescriptionMetadata.a);
        }
        if (a.j(WebGridToolbarDescriptionMetadata.a)) {
            return;
        }
        a.y(WebGridToolbarDescriptionMetadata.a);
        WebGridBaseDirectiveDescriptionMetadata.d(a);
    };
    WebGridToolbarDescriptionMetadata.c = function (a) {
        WebDisplayDensityBaseElementDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:GridToolbar");
        a.item("__tagNameWC", "String:igc-grid-toolbar");
        a.item("__packageNameWC", "String:grids");
        a.item("__manageCollectionInMarkup", "Boolean");
        a.item("__manageItemInMarkup", "Boolean");
        a.item("__mustUseNGParentAnchor", "Boolean");
        a.item("ShowProgress", "Boolean");
        a.item("Grid", "ExportedType:WebGridBaseDirective");
        a.item("Name", "String");
        a.item("Tools", "Collection:WebGridToolbarContent:WebGridToolbarContentCollection:WebGridToolbarContent");
    };
    WebGridToolbarDescriptionMetadata.d = function (a) {
        WebGridToolbarDescriptionMetadata.b(a);
        a.aa("WebGridToolbar", function () { return new WebGridToolbarDescription(); });
        a.z("WebGridToolbar", WebGridToolbarDescriptionMetadata.a);
    };
    WebGridToolbarDescriptionMetadata.$t = markType(WebGridToolbarDescriptionMetadata, 'WebGridToolbarDescriptionMetadata');
    WebGridToolbarDescriptionMetadata.a = null;
    return WebGridToolbarDescriptionMetadata;
}(Base));
export { WebGridToolbarDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebGridToolbarDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridBaseDirectiveDescriptionMetadata } from "./WebGridBaseDirectiveDescriptionMetadata";
import { WebDisplayDensityBaseElementDescriptionMetadata } from "./WebDisplayDensityBaseElementDescriptionMetadata";
import { WebGridToolbarDescription } from "./WebGridToolbarDescription";
/**
 * @hidden
 */
var WebGridToolbarDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebGridToolbarDescriptionMetadata, _super);
    function WebGridToolbarDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridToolbarDescriptionMetadata.b = function (a) {
        if (WebGridToolbarDescriptionMetadata.a == null) {
            WebGridToolbarDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridToolbarDescriptionMetadata.c(WebGridToolbarDescriptionMetadata.a);
        }
        if (a.k(WebGridToolbarDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebGridToolbarDescriptionMetadata.a);
        WebGridBaseDirectiveDescriptionMetadata.d(a);
    };
    WebGridToolbarDescriptionMetadata.c = function (a) {
        WebDisplayDensityBaseElementDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:GridToolbar");
        a.item("__tagNameWC", "String:igc-grid-toolbar");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__manageCollectionInMarkup", "Boolean");
        a.item("__manageItemInMarkup", "Boolean");
        a.item("__mustUseNGParentAnchor", "Boolean");
        a.item("ShowProgress", "Boolean");
        a.item("Grid", "ExportedType:WebGridBaseDirective");
        a.item("Name", "String");
        a.item("Tools", "Collection:WebGridToolbarContent:WebGridToolbarContentCollection:WebGridToolbarContent");
    };
    WebGridToolbarDescriptionMetadata.d = function (a) {
        WebGridToolbarDescriptionMetadata.b(a);
        a.ac("WebGridToolbar", function () { return new WebGridToolbarDescription(); });
        a.ab("WebGridToolbar", WebGridToolbarDescriptionMetadata.a);
    };
    WebGridToolbarDescriptionMetadata.$t = markType(WebGridToolbarDescriptionMetadata, 'WebGridToolbarDescriptionMetadata');
    WebGridToolbarDescriptionMetadata.a = null;
    return WebGridToolbarDescriptionMetadata;
}(Base));
export { WebGridToolbarDescriptionMetadata };
